@@ -27,6 +27,12 @@ impl VMHost {
     }
 }
 
+impl VMHost {
+    pub fn reset(&mut self) {
+        self.vm = VM::new();
+    }
+}
+
 impl VMHost {
     pub fn render(&self, pixels: &mut [u8]) {
         self.clear_screen(pixels);
